==> ELAN-3_3_0-src.zip: ELAN-3.3.0-src/src/java/mpi/eudico/server/corpora/clomimpl/dobes/LingTypeRecord.java <==
/*
 * File:     LingTypeRecord.java
 * Project:  MPI Linguistic Application
 * Date:     12 December 2007
 *
 * Copyright (C) 2001-2008  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * Created on Jun 15, 2004
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package mpi.eudico.server.corpora.clomimpl.dobes;


/**
 * @author hennie
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class LingTypeRecord {
    /** Holds value of property DOCUMENT ME! */
    public static final String ALIGNABLE = "alignable";

    /** Holds value of property DOCUMENT ME! */
    public static final String REFERENCE = "reference";

    /** Holds value of property DOCUMENT ME! */
    public static final String ALIGNABLE_SVG = "alignable_svg";
    private String lingTypeId;
    private String timeAlignable;
    private String graphicReferences;
    private String stereotype;
    private String controlledVocabulary;

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getLingTypeId() {
        return lingTypeId;
    }

    /**
     * DOCUMENT ME!
     *
     * @param lingTypeId DOCUMENT ME!
     */
    public void setLingTypeId(String lingTypeId) {
        this.lingTypeId = lingTypeId;
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getTimeAlignable() {
        return timeAlignable;
    }

    /**
     * DOCUMENT ME!
     *
     * @param timeAlignable DOCUMENT ME!
     */
    public void setTimeAlignable(String timeAlignable) {
        this.timeAlignable = timeAlignable;
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getGraphicReferences() {
        return graphicReferences;
    }

    /**
     * DOCUMENT ME!
     *
     * @param graphicReferences DOCUMENT ME!
     */
    public void setGraphicReferences(String graphicReferences) {
        this.graphicReferences = graphicReferences;
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getStereoType() {
        return stereotype;
    }

    /**
     * DOCUMENT ME!
     *
     * @param stereotype DOCUMENT ME!
     */
    public void setStereoType(String stereotype) {
        this.stereotype = stereotype;
    }

    /**
     * The name of the Controlled Vocabulary to be used by this type.
     *
     * @return name of the Controlled Vocabulary to be used by this type
     */
    public String getControlledVocabulary() {
        return controlledVocabulary;
    }

    /**
     * Sets the name of the Controlled Vocabulary to be used by this type.
     *
     * @param name he name of the Controlled Vocabulary to be used by this type
     */
    public void setControlledVocabulary(String name) {
        controlledVocabulary = name;
    }
}

==> ELAN-3_8_1-src.zip: ELAN-3.8.1-src/src/java/mpi/eudico/server/corpora/clomimpl/dobes/LingTypeRecord.java <==
/*
 * File:     LingTypeRecord.java
 * Project:  MPI Linguistic Application
 * Date:     25 August 2009
 *
 * Copyright (C) 2001-2009  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * Created on Jun 15, 2004
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package mpi.eudico.server.corpora.clomimpl.dobes;


/**
 * @author hennie
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class LingTypeRecord {
    /** Holds value of property DOCUMENT ME! */
    public static final String ALIGNABLE = "alignable";

    /** Holds value of property DOCUMENT ME! */
    public static final String REFERENCE = "reference";

    /** Holds value of property DOCUMENT ME! */
    public static final String ALIGNABLE_SVG = "alignable_svg";
    private String lingTypeId;
    private String timeAlignable;
    private String graphicReferences;
    private String stereotype;
    private String controlledVocabulary;
    private String extRefId;

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getLingTypeId() {
        return lingTypeId;
    }

    /**
     * DOCUMENT ME!
     *
     * @param lingTypeId DOCUMENT ME!
     */
    public void setLingTypeId(String lingTypeId) {
        this.lingTypeId = lingTypeId;
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getTimeAlignable() {
        return timeAlignable;
    }

    /**
     * DOCUMENT ME!
     *
     * @param timeAlignable DOCUMENT ME!
     */
    public void setTimeAlignable(String timeAlignable) {
        this.timeAlignable = timeAlignable;
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getGraphicReferences() {
        return graphicReferences;
    }

    /**
     * DOCUMENT ME!
     *
     * @param graphicReferences DOCUMENT ME!
     */
    public void setGraphicReferences(String graphicReferences) {
        this.graphicReferences = graphicReferences;
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getStereoType() {
        return stereotype;
    }

    /**
     * DOCUMENT ME!
     *
     * @param stereotype DOCUMENT ME!
     */
    public void setStereoType(String stereotype) {
        this.stereotype = stereotype;
    }

    /**
     * The name of the Controlled Vocabulary to be used by this type.
     *
     * @return name of the Controlled Vocabulary to be used by this type
     */
    public String getControlledVocabulary() {
        return controlledVocabulary;
    }

    /**
     * Sets the name of the Controlled Vocabulary to be used by this type.
     *
     * @param name he name of the Controlled Vocabulary to be used by this type
     */
    public void setControlledVocabulary(String name) {
        controlledVocabulary = name;
    }

    /**
     * Returns the id of an external reference object
     *
     * @return the extRefId the id of an external reference, e.g. a concept defined in ISO DCR
     */
    public String getExtRefId() {
        return extRefId;
    }

    /**
     * Sets the external reference id.
     *
     * @param extRefId the extRefId to set
     */
    public void setExtRefId(String extRefId) {
        this.extRefId = extRefId;
    }
}
